<!DOCTYPE html>
<html>

<head>
    <title>Django Actions</title>
</head>

<body>

    {% for action in actions %}
        <form action="do/{{ action.name_slugified }}/" method="post" >
            {% csrf_token %}
            <input type="submit" value="{{ action.name }}">
            {% for input in action.inputs %}
                <input name="{{ input }}" type="text" placeholder="{{ input }}" required>
            {% endfor %}
        </form>
    {% endfor %}

</body>


</html>