from distutils.core import setup

setup(
    name='django-actions',
    version='0.0.4',
    packages=['django_actions', ],
    long_description=open('README').read(),
    include_package_data=True,
    author='Kashif Malik',
    author_email='kashif610@gmail.com',
)
